==> react-native-code7-boteria-widget-0.1.26.tgz: package/src/components/Chat/components/Header/index.tsx <==
import React from 'react';
import { View, Image, Text, TouchableOpacity } from 'react-native';
import { useChatConfigurations } from '../../../../context/ChatConfigurations';
import { useStorage } from '../../../../context/Storage/Component';
import { useSocketActions, useEncryptedStorage } from '../../../../hooks';

import Icon from '../../../Icon';
import closeIcon from '../../../../assets/icons/CloseIcon.png';
import resetIcon from '../../../../assets/icons/ResetIcon.png';

import { styles } from './styles';

function Header() {
  const { resetMessages } = useStorage();
  const { clear } = useEncryptedStorage();
  const { subscribe } = useSocketActions();
  const { isChatOpen, toggleIsChatOpen, botConfigs } = useChatConfigurations();

  const onClose = () => !!isChatOpen && toggleIsChatOpen();

  const onRestartConversation = async () => {
    resetMessages();
    await clear();
    await subscribe();
  };

  return (
    <View
      style={[
        styles.container,
        styles.wrapper,
        {
          backgroundColor: botConfigs.colors.main,
        },
      ]}
    >
      <View style={styles.titleContainer}>
        <Icon />
        <Text style={styles.title}>{botConfigs.title}</Text>
      </View>

      <View style={styles.iconsWrapper}>
        <TouchableOpacity onPress={onRestartConversation}>
          <View style={styles.iconContainer}>
            <Image source={resetIcon} />
          </View>
        </TouchableOpacity>

        <TouchableOpacity onPress={onClose}>
          <View style={styles.iconContainer}>
            <Image source={closeIcon} />
          </View>
        </TouchableOpacity>
      </View>
    </View>
  );
}

export default Header;

==> react-native-code7-boteria-widget-0.1.28.tgz: package/src/components/Chat/components/Header/index.tsx <==
import React from 'react';
import { View, Image, Text, TouchableOpacity } from 'react-native';
import { useChatConfigurations } from '../../../../context/ChatConfigurations';
import { useStorage } from '../../../../context/Storage/Component';
import { useSocketActions, useEncryptedStorage } from '../../../../hooks';

import Icon from '../../../Icon';
import closeIcon from '../../../../assets/icons/CloseIcon.png';
import resetIcon from '../../../../assets/icons/ResetIcon.png';

import { styles } from './styles';

function Header() {
  const { resetMessages } = useStorage();
  const { clear } = useEncryptedStorage();
  const { subscribe } = useSocketActions();
  const { isChatOpen, toggleIsChatOpen, botConfigs } = useChatConfigurations();

  const onClose = () => !!isChatOpen && toggleIsChatOpen();

  const onRestartConversation = async () => {
    resetMessages();
    await Promise.all([clear(), subscribe()]);
  };

  return (
    <View
      style={[
        styles.container,
        styles.wrapper,
        {
          backgroundColor: botConfigs.colors.main,
        },
      ]}
    >
      <View style={styles.titleContainer}>
        <Icon />
        <Text style={styles.title}>{botConfigs.title}</Text>
      </View>

      <View style={styles.iconsWrapper}>
        <TouchableOpacity
          testID="restartConversation"
          onPress={onRestartConversation}
        >
          <View style={styles.iconContainer}>
            <Image source={resetIcon} />
          </View>
        </TouchableOpacity>

        <TouchableOpacity testID="closeChat" onPress={onClose}>
          <View style={styles.iconContainer}>
            <Image source={closeIcon} />
          </View>
        </TouchableOpacity>
      </View>
    </View>
  );
}

export default Header;
